@@ -11,7 +11,7 @@ class config:
             "cyan": "\x1b[36m",
         }
 
-        self.configpath = os.path.expanduser("~") + p
+        self.configpath = p
         if not os.path.exists(self.configpath):
 
             default = """# Use this color code as the accent color
