@@ -10,13 +10,17 @@ from termremind.conf import config
 
 
 def getver():
-    return "0.0.3.3"
-
+    return "0.0.4.0"
 
 VER = getver()
 
-CONF_PATH = "/.config/remind"
-REMINDERS_PATH = "/.reminds/"
+if sys.platform == "win32":
+    s = "\\"  # damn microsoft lmao
+else:
+    s = "/"
+
+CONF_PATH = os.path.expanduser("~") + s + ".config" + s + "remind"
+REMINDERS_PATH = os.path.expanduser("~") + s + ".reminds" + s
 
 RESET = "\x1b[0m"
 
@@ -58,8 +62,8 @@ def exitusage():
 If you wrap text like "%bheeho%r", it will render the text "heeho" as bright text.
 
 %REP%Notes%RES%:
-- Remind's config is located at ~/.config/remind
-- Reminders themselves are just plaintext files stored in ~/.reminds/
+- Remind's config is located at %CPTH%
+- Reminders themselves are just plaintext files stored in %RPTH%
 - "remind v" is an alias for "remind version"
 - "remind s" is an alias for "remind set"
 - "remind d" is an alias for "remind delete"
@@ -67,7 +71,12 @@ If you wrap text like "%bheeho%r", it will render the text "heeho" as bright tex
 %REP%Version%RES%: """
         + VER
     )
-    print(help.replace("%REP%", THEME_COLOR).replace("%RES%", RESET))
+    print(
+        help.replace("%REP%", THEME_COLOR)
+        .replace("%RES%", RESET)
+        .replace("%CPTH%", CONF_PATH)
+        .replace("%RPTH%", REMINDERS_PATH)
+    )
     exit(0)
 
 
@@ -113,6 +122,7 @@ def main():
         elif action == "install":
             if win:
                 print("No can do on Windows.")
+                exit(1)
             else:
                 if "bash" in shell:
                     fn = ".bashrc"
@@ -135,9 +145,11 @@ def main():
                     print("No changes made.")
         elif action == "config":
             if win:
-                print("Not yet")
+                # Can't be assed to make a config value for windows editor preference
+                # and best i can tell there's no such thing as %EDITOR% or similar
+                os.system("notepad " + CONF_PATH)  # lmk if they remove notepad lmao
             else:
-                os.system("$EDITOR " + os.path.expanduser("~") + CONF_PATH)
+                os.system("$EDITOR " + CONF_PATH)
         elif action == "edit":
             if len(sys.argv) > 3:
                 mgr.delreminder(sys.argv[2])
